/**************************************************************************************
Author:			David Szybala
Website:        www.davidszybala.com
Alt Website:    www.twistedgerbil.com
Program:		grid_lines.ms
Date:			2/10/09
Description:	This script will alter the home grid.
***************************************************************************************/

try (destroyDialog grid_lines_rollout) catch()


( --local scope
	global grid_lines_rollout
	local grid_lines_ini = getDir #plugcfg + "\\GridLines.ini"
	local grid_lines_position

	rollout grid_lines_rollout "Grid Lines"
	(
        groupBox unit_group "Units" pos:[5,5] width:220 height:60
            label scene_label "Scene Units: " pos:[15,25] width:95 height:15
            label scene_unit_label "?" pos:[115,25] width:85
            label display_label "Display Units: " pos:[15,45] width:95 height:15
            label display_unit_label "?" pos:[115,45] width:85
        
        groupBox grid_group "Grid" pos:[5,70] width:220 height:80
            label spacing_label "Spacing:" pos:[15,90] width:95 height:15
            spinner spacing_spinner "" pos:[115,90] width:50 height:15 range:[0.5,9999.0,12.0] type:#float scale:1
            dropdownlist spacing_dropdown "" pos:[175,88] width:40 height:7 items:#("in","ft","mm","cm","m","km")
            label major_line_label "Major Lines Every:" pos:[15,110] width:95 height:15
            spinner major_line_spinner "" pos:[115,110] width:50 height:15 range:[2,9999,5] type:#integer scale:1
            label grid_extent_label "Persp Grid Extent:" pos:[15,130] width:95 height:15
            spinner grid_extent_spinner "" pos:[115,130] width:50 height:15 range:[1,9999,10] type:#integer scale:1
        
        button grid_button "Change Grid Lines" pos:[5,160] width:220 height:20
        label status_label "INFO: Standing by..." pos:[5,190] width:220 height:15
		
        /**********************************************************************
        UI open event handler. Prepares the UI for first time open
        **********************************************************************/
        on grid_lines_rollout open do
        (
            local display_type = ""
            
            case units.DisplayType of
            (
                (#Generic): display_type = "generic"
                (#Metric): display_type = (units.MetricType as string)
                (#US): display_type = (units.USType as string)
                (#custom): display_type = (units.CustomName as string)
            ) --end case
            
            scene_unit_label.text = (units.SystemType as string)
            display_unit_label.text = display_type
        ) --end on
        
        /**********************************************************************
        UI move event handler. Stores the current position of the UI
        **********************************************************************/
		on grid_lines_rollout moved pos do
            setIniSetting grid_lines_ini "Dialog" "Position" (pos as string)
        
        /**********************************************************************
        Grid button click event handler. Alters the home grid
        **********************************************************************/
        on grid_button pressed do
        (
            local spacing_value = (spacing_spinner.value as string)
            local converted_value = 0.0
            local message = ""
            
            case spacing_dropdown.selected of
            (
                ("in"): spacing_value += "\""
                ("ft"): spacing_value += "'"
                ("mm"): spacing_value += "mm"
                ("cm"): spacing_value += "cm"
                ("m"): spacing_value += "m"
                ("km"): spacing_value += "km"
            ) --end case
            
            try
            (
                converted_value = units.decodeValue spacing_value
            ) --end try
            catch
            (
                status_label.text = "ERROR: Could not convert spacing value"
                return false
            ) --end catch
            
            gridPrefs.spacing = converted_value
            gridPrefs.majorLines = major_line_spinner.value
            gridPrefs.perspViewGridExtents = grid_extent_spinner.value
            
            message = "INFO: Grid lines set to "
            message += (spacing_spinner.value as string) + spacing_dropdown.selected
            status_label.text = message
        ) --end on
	) --end rollout
    
	grid_lines_position = execute (getIniSetting grid_lines_ini "Dialog" "Position")
	if grid_lines_position == OK do grid_lines_position = [100,100]
	if grid_lines_position.x > sysinfo.desktopsize.x - 230 do
        grid_lines_position.x = sysinfo.desktopsize.x - 235
	if grid_lines_position.y > sysinfo.desktopsize.y - 265 do
        grid_lines_position.y = sysinfo.desktopsize.y - 265
	if grid_lines_position.x < 0 do grid_lines_position.x = 0 
	if grid_lines_position.y < 0 do grid_lines_position.y = 0
	createDialog grid_lines_rollout 230 205 grid_lines_position.x grid_lines_position.y
) --end local scope